IS_RELEASE = True

from .ScreenData import ScreenData
from .ScreenStWidgets import StreamlitNativeWidgetScreen
from .WindowScreenQuery import WindowQuerySize
from .SizeRange import WindowScreenRange



